--[[
	Copyright (C) Udorn (Blackhand)
--]]

petbm = petbm or {}

petbm.PetBattleMaster = LibStub("AceAddon-3.0"):NewAddon("PetBattleMaster", "AceEvent-3.0", "AceConsole-3.0", "AceHook-3.0")
--local L = petbm.Locale.GetInstance()
local log = petbm.Debug:new("PetBattleMaster")

local AceConfigDialog = LibStub("AceConfigDialog-3.0")

local APP_NAME = "PetBattleMaster"

local order = 1

local SCREEN_HEIGHT = GetScreenHeight()
local SCREEN_WIDTH = GetScreenWidth()
local ICON = "Interface\\Icons\\Ability_Hunter_AspectoftheFox"

local DEFAULT_CONFIG = {
	profile = {
		frames = {},
		teams = {},
		minimapIcon = {}
	}
}

local function _Open(self)
	log:Debug("_Open")
	self.view:Open()
	self.view:PetChanged()
	log:Debug("_Open exit")
end

function petbm.PetBattleMaster:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("PetBattleMasterDb", DEFAULT_CONFIG, "Default")
--	OPTIONS.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)
	
	self.db.RegisterCallback(self, "OnProfileChanged", "ProfileUpdate")
	self.db.RegisterCallback(self, "OnProfileCopied", "ProfileUpdate")
	self.db.RegisterCallback(self, "OnProfileReset", "ProfileUpdate")
end

function petbm.PetBattleMaster:OnEnable()
	log:Debug("OnEnable")
	log:ClearHistory()
	self.view = petbm.PetInfoView.New()
--	LibStub("AceConfig-3.0"):RegisterOptionsTable(APP_NAME, OPTIONS)
--	self.configFrame = AceConfigDialog:AddToBlizOptions(APP_NAME)
	self:RegisterChatCommand("petbm", "ChatCommand")
	
	self:RegisterEvent("PET_BATTLE_PET_CHANGED")	
	self:RegisterEvent("PET_BATTLE_OPENING_START")
	self:RegisterEvent("PET_BATTLE_OPENING_DONE")
	--self:RegisterEvent("PET_BATTLE_OVER")
	self:RegisterEvent("PET_BATTLE_CLOSE")
	self:SecureHook(C_PetJournal, "SetSearchFilter")
	
	-- libdatabroker integration
	local ldb = LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject("PetBattleMaster", {
		type = "launcher",
		icon = ICON,
		label = "PetBattleMaster",
		OnClick = function(clickedframe, button)
			petbm.PetTeamView:ToggleView()
		end,
	})
	LibStub("LibDBIcon-1.0"):Register("PetBattleMaster", ldb, self.db.profile.minimapIcon)
	
	-- perhaps we are still in combat
	if (C_PetBattles.IsInBattle()) then
		_Open(self)
	end
end

function petbm.PetBattleMaster:ProfileUpdate(event)
	log:Debug("ProfileUpdate event [%s]", event)
	self.view:ProfileUpdate()
end

function petbm.PetBattleMaster:ChatCommand(msg)
	log:Debug("msg [%s]", msg)
	if ("debug" == msg) then
		if (log:IsDebugging()) then
			print("Turning off debugging")
			log:SetDebugging(nil)
		else
			print("Turning on debugging")
			log:SetDebugging(true)
		end
	elseif ("history" == msg) then
		print("Printing history")
		log:PrintHistory()
	elseif ("clear" == msg) then
		print("Clearing history")
		log:ClearHistory()
--	else
--		InterfaceOptionsFrame_OpenToCategory(self.configFrame)
	end
end

function petbm.PetBattleMaster.Print(self, msg)
	print("|cFF3DDEFF"..msg.."|r")
end

function petbm.PetBattleMaster:PET_BATTLE_PET_CHANGED()
	log:Debug("PET_BATTLE_PET_CHANGED")
	self.view:PetChanged()
end

function petbm.PetBattleMaster:PET_BATTLE_OPENING_START()
	log:Debug("PET_BATTLE_OPENING_START")
	-- TODO is there any way to do this here without a bug, because the DONE event doesn't 
	-- occur after a reload :-( Seems to be bugged...
	--_Open(self)
end

function petbm.PetBattleMaster:PET_BATTLE_OPENING_DONE()
	log:Debug("PET_BATTLE_OPENING_DONE")
	_Open(self)
end

function petbm.PetBattleMaster:PET_BATTLE_CLOSE()
	log:Debug("PET_BATTLE_CLOSE")
	self.view:Close()
end

function petbm.PetBattleMaster:SetSearchFilter(text)
	log:Debug("SetSearchFilter text [%s]", text)
	self.searchText = text
end
